@@ -448,6 +448,10 @@ class LoadMaster(HttpClient):
                        format(ip=self.ip_address, port=self.port))
                 resp = self._tls_session.get(url, verify=False, timeout=1,
                                              cert=self.cert)
+                url = ("https://{ip}:{port}/progs/status/logout".
+                       format(ip=self.ip_address, port=self.port))
+                self._tls_session.get(url, verify=False, timeout=1,
+                                      cert=self.cert)
             else:
                 url = ("https://{user}:{pw}@{ip}:{port}/progs/doconfig/"
                        "enableapi/set/yes").format(user=self.username,
@@ -455,6 +459,12 @@ class LoadMaster(HttpClient):
                                                    ip=self.ip_address,
                                                    port=self.port)
                 resp = self._tls_session.get(url, verify=False, timeout=1)
+                url = ("https://{user}:{pw}@{ip}:{port}/progs/status/logout"
+                       ).format(user=self.username,
+                                pw=self.password,
+                                ip=self.ip_address,
+                                port=self.port)
+                resp = self._tls_session.get(url, verify=False, timeout=1)
             self._tls_session.close()
             resp.raise_for_status()
             return True
@@ -727,9 +737,8 @@ class VirtualService(HttpClient, KempBaseObjectModel):
     def to_api_dict(self):
         api = super(VirtualService, self).to_api_dict()
         if not self._waf:
-            for key, value in api.items():
-                if key in self._waf_params:
-                    del api[key]
+            for entry in self._waf_params:
+                del api[entry]
         return api
 
     def _get_base_parameters(self):
